@@ -7,7 +7,11 @@ import wrapt
 
 
 # Can set to True to enable debug messages.
-DEBUG_CONTRACTS = True
+DEBUG_CONTRACTS = False
+
+
+class PyTAContractError(Exception):
+    """Error raised when a PyTA contract assertion is violated."""
 
 
 def check_all_contracts(*args, decorate_main=True) -> None:
@@ -43,7 +47,7 @@ def check_contracts(wrapped, instance, args, kwargs):
             return _check_function_contracts(wrapped, None, args, kwargs)
         else:
             return _check_function_contracts(wrapped, instance, args, kwargs)
-    except AssertionError as e:
+    except PyTAContractError as e:
         raise AssertionError(str(e)) from None
 
 
@@ -86,11 +90,12 @@ def add_class_invariants(klass: type) -> None:
         frame_locals = callframe[1].frame.f_locals
         if self is not frame_locals.get('self'):
             # Only validating if the attribute is not being set in a instance/class method
-            init = getattr(klass, '__init__')
-            try:
-                _check_invariants(self, rep_invariants, init.__globals__)
-            except AssertionError as e:
-                raise AssertionError(str(e)) from None
+            klass_mod = sys.modules.get(klass.__module__)
+            if klass_mod is not None:
+                try:
+                    _check_invariants(self, rep_invariants, klass_mod.__dict__)
+                except PyTAContractError as e:
+                    raise AssertionError(str(e)) from None
 
     for attr, value in klass.__dict__.items():
         if inspect.isroutine(value):
@@ -115,9 +120,9 @@ def _check_function_contracts(wrapped, instance, args, kwargs):
                 _debug(f'Checking type of parameter {param} in call to {wrapped.__qualname__}')
                 check_type(param, arg, annotations[param])
             except TypeError:
-                raise AssertionError(
-                    f'{wrapped.__name__} argument {repr(arg)} did not match type annotation for parameter \
-                        "{param}: {annotations[param]}"')
+                raise PyTAContractError(
+                    f'{wrapped.__name__} argument {repr(arg)} did not match type annotation for parameter '
+                    f'"{param}: {annotations[param]}"')
 
     # Check function preconditions
     preconditions = parse_assertions(wrapped)
@@ -132,7 +137,7 @@ def _check_function_contracts(wrapped, instance, args, kwargs):
             _debug(f'Checking return type from call to {wrapped.__qualname__}')
             check_type('return', r, return_type)
         except TypeError:
-            raise AssertionError(
+            raise PyTAContractError(
                 f'{wrapped.__name__} return value {r} does not match annotated return type {return_type}')
 
     return r
@@ -144,12 +149,13 @@ def _instance_method_wrapper(wrapped, rep_invariants=None):
 
     @wrapt.decorator
     def wrapper(wrapped, instance, args, kwargs):
-        init = getattr(instance, '__init__')
         try:
             r = _check_function_contracts(wrapped, instance, args, kwargs)
-            _check_invariants(instance, rep_invariants, init.__globals__)
+            klass_mod = sys.modules.get(type(instance).__module__)
+            if klass_mod is not None:
+                _check_invariants(instance, rep_invariants, klass_mod.__dict__)
             _check_class_type_annotations(instance)
-        except AssertionError as e:
+        except PyTAContractError as e:
             raise AssertionError(str(e)) from None
         else:
             return r
@@ -178,12 +184,12 @@ def _check_invariants(instance, rep_invariants: Set[str], global_scope: dict) ->
     for invariant in rep_invariants:
         try:
             _debug(f'Checking representation invariant for {instance.__class__.__qualname__}: {invariant}')
-            check = eval(invariant, global_scope, {'self': instance})
+            check = eval(invariant, {**global_scope, 'self': instance})
         except:
             _debug(f'Warning: could not evaluate representation invariant: {invariant}')
         else:
-            assert check,\
-                f'Representation invariant "{invariant}" violated.'
+            if not check:
+                raise PyTAContractError(f'Representation invariant "{invariant}" violated.')
 
 
 def _check_assertions(wrapped: Callable[..., Any], function_locals: dict, assertions: List[str]) -> None:
@@ -192,12 +198,13 @@ def _check_assertions(wrapped: Callable[..., Any], function_locals: dict, assert
     for assertion in assertions:
         try:
             _debug(f'Checking precondition for {wrapped.__qualname__}: {assertion}')
-            check = eval(assertion, wrapped.__globals__, function_locals)
+            check = eval(assertion, {**wrapped.__globals__, **function_locals})
         except:
             _debug(f'Warning: could not evaluate precondition: {assertion}')
         else:
-            assert check,\
-                f'{wrapped.__name__} precondition "{assertion}" violated for arguments {function_locals}.'
+            if not check:
+                raise PyTAContractError(f'{wrapped.__name__} precondition "{assertion}" '
+                                        f'violated for arguments {function_locals}.')
 
 
 def parse_assertions(obj: Any, parse_token: str = 'Precondition') -> List[str]:
